<?php

namespace Litecms\Latesttransaction\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Latesttransaction\Http\Requests\LatesttransactionRequest;
use Litecms\Latesttransaction\Interfaces\LatesttransactionRepositoryInterface;
use Litecms\Latesttransaction\Models\Latesttransaction;

/**
 * Resource controller class for latesttransaction.
 */
class LatesttransactionResourceController extends BaseController
{

    /**
     * Initialize latesttransaction resource controller.
     *
     * @param type LatesttransactionRepositoryInterface $latesttransaction
     *
     * @return null
     */
    public function __construct(LatesttransactionRepositoryInterface $latesttransaction)
    {
        parent::__construct();
        $this->repository = $latesttransaction;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Latesttransaction\Repositories\Criteria\LatesttransactionResourceCriteria::class);
    }

    /**
     * Display a list of latesttransaction.
     *
     * @return Response
     */
    public function index(LatesttransactionRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Latesttransaction\Repositories\Presenter\LatesttransactionPresenter::class)
                ->$function();
        }

        $latesttransactions = $this->repository->paginate();

        return $this->response->title(trans('latesttransaction::latesttransaction.names'))
            ->view('latesttransaction::latesttransaction.index', true)
            ->data(compact('latesttransactions'))
            ->output();
    }

    /**
     * Display latesttransaction.
     *
     * @param Request $request
     * @param Model   $latesttransaction
     *
     * @return Response
     */
    public function show(LatesttransactionRequest $request, Latesttransaction $latesttransaction)
    {

        if ($latesttransaction->exists) {
            $view = 'latesttransaction::latesttransaction.show';
        } else {
            $view = 'latesttransaction::latesttransaction.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('latesttransaction::latesttransaction.name'))
            ->data(compact('latesttransaction'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new latesttransaction.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LatesttransactionRequest $request)
    {

        $latesttransaction = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('latesttransaction::latesttransaction.name')) 
            ->view('latesttransaction::latesttransaction.create', true) 
            ->data(compact('latesttransaction'))
            ->output();
    }

    /**
     * Create new latesttransaction.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LatesttransactionRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $latesttransaction                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('latesttransaction::latesttransaction.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('latesttransaction/latesttransaction/' . $latesttransaction->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/latesttransaction/latesttransaction'))
                ->redirect();
        }

    }

    /**
     * Show latesttransaction for editing.
     *
     * @param Request $request
     * @param Model   $latesttransaction
     *
     * @return Response
     */
    public function edit(LatesttransactionRequest $request, Latesttransaction $latesttransaction)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('latesttransaction::latesttransaction.name'))
            ->view('latesttransaction::latesttransaction.edit', true)
            ->data(compact('latesttransaction'))
            ->output();
    }

    /**
     * Update the latesttransaction.
     *
     * @param Request $request
     * @param Model   $latesttransaction
     *
     * @return Response
     */
    public function update(LatesttransactionRequest $request, Latesttransaction $latesttransaction)
    {
        try {
            $attributes = $request->all();

            $latesttransaction->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('latesttransaction::latesttransaction.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('latesttransaction/latesttransaction/' . $latesttransaction->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('latesttransaction/latesttransaction/' . $latesttransaction->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the latesttransaction.
     *
     * @param Model   $latesttransaction
     *
     * @return Response
     */
    public function destroy(LatesttransactionRequest $request, Latesttransaction $latesttransaction)
    {
        try {

            $latesttransaction->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('latesttransaction::latesttransaction.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('latesttransaction/latesttransaction/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('latesttransaction/latesttransaction/' . $latesttransaction->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple latesttransaction.
     *
     * @param Model   $latesttransaction
     *
     * @return Response
     */
    public function delete(LatesttransactionRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('latesttransaction::latesttransaction.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('latesttransaction/latesttransaction'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/latesttransaction/latesttransaction'))
                ->redirect();
        }

    }

    /**
     * Restore deleted latesttransactions.
     *
     * @param Model   $latesttransaction
     *
     * @return Response
     */
    public function restore(LatesttransactionRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('latesttransaction::latesttransaction.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/latesttransaction/latesttransaction'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/latesttransaction/latesttransaction/'))
                ->redirect();
        }

    }

}
