<?php

namespace Litecms\Latesttransaction\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Latesttransaction\Models\Latesttransaction;

class LatesttransactionPolicy
{

    /**
     * Determine if the given user can view the latesttransaction.
     *
     * @param UserPolicy $user
     * @param Latesttransaction $latesttransaction
     *
     * @return bool
     */
    public function view(UserPolicy $user, Latesttransaction $latesttransaction)
    {
        if ($user->canDo('latesttransaction.latesttransaction.view') && $user->isAdmin()) {
            return true;
        }

        return $latesttransaction->user_id == user_id() && $latesttransaction->user_type == user_type();
    }

    /**
     * Determine if the given user can create a latesttransaction.
     *
     * @param UserPolicy $user
     * @param Latesttransaction $latesttransaction
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('latesttransaction.latesttransaction.create');
    }

    /**
     * Determine if the given user can update the given latesttransaction.
     *
     * @param UserPolicy $user
     * @param Latesttransaction $latesttransaction
     *
     * @return bool
     */
    public function update(UserPolicy $user, Latesttransaction $latesttransaction)
    {
        if ($user->canDo('latesttransaction.latesttransaction.edit') && $user->isAdmin()) {
            return true;
        }

        return $latesttransaction->user_id == user_id() && $latesttransaction->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given latesttransaction.
     *
     * @param UserPolicy $user
     * @param Latesttransaction $latesttransaction
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Latesttransaction $latesttransaction)
    {
        return $latesttransaction->user_id == user_id() && $latesttransaction->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given latesttransaction.
     *
     * @param UserPolicy $user
     * @param Latesttransaction $latesttransaction
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Latesttransaction $latesttransaction)
    {
        if ($user->canDo('latesttransaction.latesttransaction.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given latesttransaction.
     *
     * @param UserPolicy $user
     * @param Latesttransaction $latesttransaction
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Latesttransaction $latesttransaction)
    {
        if ($user->canDo('latesttransaction.latesttransaction.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
